@@ -113,8 +113,16 @@ void	    glade_show_widget_tooltips		(gboolean	show);
 
 void	    glade_show_grid			(gboolean	show);
 void	    glade_snap_to_grid			(gboolean	snap);
+#if 0
+/* Changed editor_show_grid_settings_dialog and
+   editor_show_grid_settings_dialog to take a widget parameter, to use for
+   selecting a transient parent.
+   These functions don't know about any widgets. Since they're unused,
+   they're commented out. I guess it would be even better to remove them
+   outright. */
 void	    glade_show_grid_settings		(void);
 void	    glade_show_snap_settings		(void);
+#endif
 
 gchar*	    glade_get_error_message		(GladeStatusCode  status);
 
